@@ -282,3 +282,41 @@ class DistributionOnDiskEggSource(DistributionOnDiskEgg):
         metadata_finder = pkg_resources.PathMetadata(self.dist_path, egg_info)
         return  metadata_finder
 
+def datapkg_index(dist, attr, value):
+    """
+    This is the implementation for an [egg_info.writers] entrypoint.
+    Datapkg adds an argument to setuptools's setup() function called
+    datapkg_sources. The argument should be string not unlike the 
+    manifest. For example,
+
+    .. code-block:: python
+
+        setup(
+            ...,
+            datapkg_index = \"""
+                [cra2009]
+                title=HM Treasury's Country and Regional Analysis 2009
+                download_url=http://www.hm-treasury.gov.uk/d/cra_2009_db.csv
+            \"""
+        )
+        
+    The result of this is that there will be a file in the egg called
+    datapkg_index.txt with those contents (lines are stripped of
+    whitespace).
+
+    The :class:`datapkg.index.egg.EggIndex` class will take the section
+    headers and turn them into the name of the dataset, other keys are
+    passed along unchanged into the resulting package.
+
+    How do you get at this data? Simple::
+
+    .. code-block:: python
+
+        import pkg_resources
+        dist = pkg_resources.get_distribution("ukgov_treasury_cra")
+        spec = dist.get_metadata("datapkg_index.txt")
+
+    and 'spec' will be the contents of the file as a string.
+    """
+    spec = [line.strip() for line in value.split("\n")]
+    setattr(dist, attr, spec)
